#!/usr/bin/env bash
###############################################################################
#
# Bash Remediation Script for Java Runtime Environment (JRE) STIG
#
# Profile Description:
# The Java Runtime Environment (JRE) is a bundle developed
# and offered by Oracle Corporation which includes the Java Virtual Machine
# (JVM), class libraries, and other components necessary to run Java
# applications and applets. Certain default settings within the JRE pose
# a security risk so it is necessary to deploy system wide properties to
# ensure a higher degree of security when utilizing the JRE.
# The IBM Corporation also develops and bundles the Java Runtime Environment
# (JRE) as well as Red Hat with OpenJDK.
#
# Profile ID:  stig
# Benchmark ID:  JRE
# Benchmark Version:  0.1.53
# XCCDF Version:  1.1
#
# This file was generated by OpenSCAP 1.3.4 using:
# $ oscap xccdf generate fix --profile stig --fix-type bash xccdf-file.xml
#
# This Bash Remediation Script is generated from an OpenSCAP profile without preliminary evaluation.
# It attempts to fix every selected rule, even if the system is already compliant.
#
# How to apply this Bash Remediation Script:
# $ sudo ./remediation-script.sh
#
###############################################################################

###############################################################################
# BEGIN fix (1 / 24) for 'java_jre_clean_previous_version'
###############################################################################
(>&2 echo "Remediating rule 1/24: 'java_jre_clean_previous_version'")

if grep --silent ^clean_requirements_on_remove /etc/yum.conf ; then
        sed -i "s/^clean_requirements_on_remove.*/clean_requirements_on_remove=1/g" /etc/yum.conf
else
        echo -e "\n# Set clean_requirements_on_remove to 1 per security requirements" >> /etc/yum.conf
        echo "clean_requirements_on_remove=1" >> /etc/yum.conf
fi

# END fix for 'java_jre_clean_previous_version'

###############################################################################
# BEGIN fix (2 / 24) for 'java_jre_insecure_prompt'
###############################################################################
(>&2 echo "Remediating rule 2/24: 'java_jre_insecure_prompt'")
JAVA_PROPERTIES="/etc/.java/deployment/deployment.properties"

grep -q "^deployment.insecure.jres=.*$" ${JAVA_PROPERTIES} && \
sed -i "s/deployment.insecure.jres=.*/deployment.insecure.jres=PROMPT/g" ${JAVA_PROPERTIES}
if ! [ $? -eq 0 ] ; then
  echo "deployment.insecure.jres=PROMPT" >> ${JAVA_PROPERTIES}
fi

# END fix for 'java_jre_insecure_prompt'

###############################################################################
# BEGIN fix (3 / 24) for 'java_jre_validation_ocsp_locked'
###############################################################################
(>&2 echo "Remediating rule 3/24: 'java_jre_validation_ocsp_locked'")
JAVA_PROPERTIES="/etc/.java/deployment/deployment.properties"

grep -q "^deployment.security.validation.ocsp.locked$" ${JAVA_PROPERTIES}

if ! [ $? -eq 0 ] ; then
  echo "deployment.security.validation.ocsp.locked" >> ${JAVA_PROPERTIES}
fi

# END fix for 'java_jre_validation_ocsp_locked'

###############################################################################
# BEGIN fix (4 / 24) for 'java_jre_lock_untrusted_sources'
###############################################################################
(>&2 echo "Remediating rule 4/24: 'java_jre_lock_untrusted_sources'")
JAVA_PROPERTIES="/etc/.java/deployment/deployment.properties"

grep -q "^deployment.security.askgrantdialog.show=.*$" ${JAVA_PROPERTIES} && \
sed -i "s/deployment.security.askgrantdialog.show=.*/deployment.security.askgrantdialog.show=false/g" ${JAVA_PROPERTIES}
if ! [ $? -eq 0 ] ; then
  echo "deployment.security.askgrantdialog.show=false" >> ${JAVA_PROPERTIES}
fi

# END fix for 'java_jre_lock_untrusted_sources'

###############################################################################
# BEGIN fix (5 / 24) for 'java_jre_unsigned_applications'
###############################################################################
(>&2 echo "Remediating rule 5/24: 'java_jre_unsigned_applications'")
JAVA_PROPERTIES="/etc/.java/deployment/deployment.properties"

grep -q "^deployment.security.level=.*$" ${JAVA_PROPERTIES} && \
sed -i "s/deployment.security.level=.*/deployment.security.level=VERY_HIGH/g" ${JAVA_PROPERTIES}
if ! [ $? -eq 0 ] ; then
  echo "deployment.security.level=VERY_HIGH" >> ${JAVA_PROPERTIES}
fi

# END fix for 'java_jre_unsigned_applications'

###############################################################################
# BEGIN fix (6 / 24) for 'java_jre_updated'
###############################################################################
(>&2 echo "Remediating rule 6/24: 'java_jre_updated'")


yum -y update

# END fix for 'java_jre_updated'

###############################################################################
# BEGIN fix (7 / 24) for 'java_jre_validation_crl'
###############################################################################
(>&2 echo "Remediating rule 7/24: 'java_jre_validation_crl'")
JAVA_PROPERTIES="/etc/.java/deployment/deployment.properties"

grep -q "^deployment.security.validation.crl=.*" ${JAVA_PROPERTIES} && \
sed -i "s/deployment.security.validation.crl=.*/deployment.security.validation.crl=true/g" ${JAVA_PROPERTIES}
if ! [ $? -eq 0 ] ; then
  echo "deployment.security.validation.crl=true" >> ${JAVA_PROPERTIES}
fi

# END fix for 'java_jre_validation_crl'

###############################################################################
# BEGIN fix (8 / 24) for 'java_jre_enable_jws'
###############################################################################
(>&2 echo "Remediating rule 8/24: 'java_jre_enable_jws'")
JAVA_PROPERTIES="/etc/.java/deployment/deployment.properties"

grep -q "^deployment.webjava.enabled=.*$" ${JAVA_PROPERTIES} && \
sed -i "s/deployment.webjava.enabled=.*/deployment.webjava.enabled=true/g" ${JAVA_PROPERTIES}
if ! [ $? -eq 0 ] ; then
  echo "deployment.webjava.enabled=true" >> ${JAVA_PROPERTIES}
fi

# END fix for 'java_jre_enable_jws'

###############################################################################
# BEGIN fix (9 / 24) for 'java_jre_blacklist_check_locked'
###############################################################################
(>&2 echo "Remediating rule 9/24: 'java_jre_blacklist_check_locked'")
JAVA_PROPERTIES="/etc/.java/deployment/deployment.properties"

grep -q "^deployment.webjava.enabled.locked$" ${JAVA_PROPERTIES}
if ! [ $? -eq 0 ] ; then
  echo "deployment.webjava.enabled.locked" >> ${JAVA_PROPERTIES}
fi

# END fix for 'java_jre_blacklist_check_locked'

###############################################################################
# BEGIN fix (10 / 24) for 'java_jre_validation_crl_locked'
###############################################################################
(>&2 echo "Remediating rule 10/24: 'java_jre_validation_crl_locked'")
JAVA_PROPERTIES="/etc/.java/deployment/deployment.properties"

grep -q "^deployment.security.validation.crl.locked$" ${JAVA_PROPERTIES}
if ! [ $? -eq 0 ] ; then
  echo "deployment.security.validation.crl.locked" >> ${JAVA_PROPERTIES}
fi

# END fix for 'java_jre_validation_crl_locked'

###############################################################################
# BEGIN fix (11 / 24) for 'java_jre_lock_untrusted_sources_locked'
###############################################################################
(>&2 echo "Remediating rule 11/24: 'java_jre_lock_untrusted_sources_locked'")
JAVA_PROPERTIES="/etc/.java/deployment/deployment.properties"

grep -q "^deployment.security.askgrantdialog.show.locked$" ${JAVA_PROPERTIES}
if ! [ $? -eq 0 ] ; then
  echo "deployment.security.askgrantdialog.show.locked" >> ${JAVA_PROPERTIES}
fi

# END fix for 'java_jre_lock_untrusted_sources_locked'

###############################################################################
# BEGIN fix (12 / 24) for 'java_jre_unsigned_applications_locked'
###############################################################################
(>&2 echo "Remediating rule 12/24: 'java_jre_unsigned_applications_locked'")
JAVA_PROPERTIES="/etc/.java/deployment/deployment.properties"

grep -q "^deployment.security.level.locked$" ${JAVA_PROPERTIES}
if ! [ $? -eq 0 ] ; then
  echo "deployment.security.level.locked" >> ${JAVA_PROPERTIES}
fi

# END fix for 'java_jre_unsigned_applications_locked'

###############################################################################
# BEGIN fix (13 / 24) for 'java_jre_blacklist_check'
###############################################################################
(>&2 echo "Remediating rule 13/24: 'java_jre_blacklist_check'")
JAVA_PROPERTIES="/etc/.java/deployment/deployment.properties"

grep -q "^deployment.security.blacklist.check=.*$" ${JAVA_PROPERTIES} && \
sed -i "s/deployment.security.blacklist.check=.*/deployment.security.blacklist.check=true/g" ${JAVA_PROPERTIES}
if ! [ $? -eq 0 ] ; then
  echo "deployment.security.blacklist.check=true" >> ${JAVA_PROPERTIES}
fi

# END fix for 'java_jre_blacklist_check'

###############################################################################
# BEGIN fix (14 / 24) for 'java_jre_deployment_properties_exists'
###############################################################################
(>&2 echo "Remediating rule 14/24: 'java_jre_deployment_properties_exists'")
JAVA_PROPERTIES="/etc/.java/deployment/deployment.properties"
JAVA_DIR="/etc/.java/deployment"

if [ ! -d ${JAVA_DIR} ] ; then
  mkdir -p -m 755 ${JAVA_DIR}
fi

if [ ! -e ${JAVA_PROPERTIES} ]; then
  touch ${JAVA_PROPERTIES} && chmod 644 ${JAVA_PROPERTIES}
fi

chmod 644 ${JAVA_PROPERTIES}

# END fix for 'java_jre_deployment_properties_exists'

###############################################################################
# BEGIN fix (15 / 24) for 'java_jre_disable_untrusted_sources_locked'
###############################################################################
(>&2 echo "Remediating rule 15/24: 'java_jre_disable_untrusted_sources_locked'")
JAVA_PROPERTIES="/etc/.java/deployment/deployment.properties"

grep -q "^deployment.security.askgrantdialog.notinca.locked$" ${JAVA_PROPERTIES}
if ! [ $? -eq 0 ] ; then
  echo "deployment.security.askgrantdialog.notinca.locked" >> ${JAVA_PROPERTIES}
fi

# END fix for 'java_jre_disable_untrusted_sources_locked'

###############################################################################
# BEGIN fix (16 / 24) for 'java_jre_disable_untrusted_sources'
###############################################################################
(>&2 echo "Remediating rule 16/24: 'java_jre_disable_untrusted_sources'")
JAVA_PROPERTIES="/etc/.java/deployment/deployment.properties"

grep -q "^deployment.security.askgrantdialog.notinca=.*$" ${JAVA_PROPERTIES} && \
sed -i "s/deployment.security.askgrantdialog.notinca=.*/deployment.security.askgrantdialog.notinca=false/g" ${JAVA_PROPERTIES}
if ! [ $? -eq 0 ] ; then
  echo "deployment.security.askgrantdialog.notinca=false" >> ${JAVA_PROPERTIES}
fi

# END fix for 'java_jre_disable_untrusted_sources'

###############################################################################
# BEGIN fix (17 / 24) for 'java_jre_insecure_prompt_locked'
###############################################################################
(>&2 echo "Remediating rule 17/24: 'java_jre_insecure_prompt_locked'")
JAVA_PROPERTIES="/etc/.java/deployment/deployment.properties"

grep -q "^deployment.insecure.jres.locked$" ${JAVA_PROPERTIES}
if ! [ $? -eq 0 ] ; then
  echo "deployment.insecure.jres.locked" >> ${JAVA_PROPERTIES}
fi

# END fix for 'java_jre_insecure_prompt_locked'

###############################################################################
# BEGIN fix (18 / 24) for 'java_jre_enable_jws_locked'
###############################################################################
(>&2 echo "Remediating rule 18/24: 'java_jre_enable_jws_locked'")
JAVA_PROPERTIES="/etc/.java/deployment/deployment.properties"

grep -q "^deployment.webjava.enabled.locked$" ${JAVA_PROPERTIES}
if ! [ $? -eq 0 ] ; then
  echo "deployment.webjava.enabled.locked" >> ${JAVA_PROPERTIES}
fi

# END fix for 'java_jre_enable_jws_locked'

###############################################################################
# BEGIN fix (19 / 24) for 'java_jre_validation_ocsp'
###############################################################################
(>&2 echo "Remediating rule 19/24: 'java_jre_validation_ocsp'")
JAVA_PROPERTIES="/etc/.java/deployment/deployment.properties"

grep -q "^deployment.security.validation.ocsp=.*" ${JAVA_PROPERTIES} && \
sed -i "s/deployment.security.validation.ocsp=.*/deployment.security.validation.ocsp=true/g" ${JAVA_PROPERTIES}
if ! [ $? -eq 0 ] ; then
  echo "deployment.security.validation.ocsp=true" >> ${JAVA_PROPERTIES}
fi

# END fix for 'java_jre_validation_ocsp'

###############################################################################
# BEGIN fix (20 / 24) for 'java_jre_deployment_config_properties'
###############################################################################
(>&2 echo "Remediating rule 20/24: 'java_jre_deployment_config_properties'")
JAVA_CONFIG="/etc/.java/deployment/deployment.config"
JAVA_PROPERTIES="/etc/.java/deployment/deployment.properties"

grep -q "^deployment.system.config=.*" ${JAVA_CONFIG} && \
sed -i "s;deployment.system.config=.*;deployment.system.config=file:\/\/${JAVA_PROPERTIES};g" ${JAVA_CONFIG}
if ! [ $? -eq 0 ] ; then
  echo "deployment.system.config=file://${JAVA_PROPERTIES}" >> ${JAVA_CONFIG}
fi

# END fix for 'java_jre_deployment_config_properties'

###############################################################################
# BEGIN fix (21 / 24) for 'java_jre_deployment_config_mandatory'
###############################################################################
(>&2 echo "Remediating rule 21/24: 'java_jre_deployment_config_mandatory'")
JAVA_CONFIG="/etc/.java/deployment/deployment.config"

grep -q "^deployment.system.config.mandatory=.*" ${JAVA_CONFIG} && \
sed -i "s/deployment.system.config.mandatory=.*/deployment.system.config.mandatory=true/g" ${JAVA_CONFIG}
if ! [ $? -eq 0 ] ; then
  echo "deployment.system.config.mandatory=true" >> ${JAVA_CONFIG}
fi

# END fix for 'java_jre_deployment_config_mandatory'

###############################################################################
# BEGIN fix (22 / 24) for 'java_jre_deployment_config_exists'
###############################################################################
(>&2 echo "Remediating rule 22/24: 'java_jre_deployment_config_exists'")
JAVA_CONFIG="/etc/.java/deployment/deployment.config"
JAVA_DIR="/etc/.java/deployment"

if [ ! -d ${JAVA_DIR} ] ; then
  mkdir -p -m 755 ${JAVA_DIR}
fi

if [ ! -e ${JAVA_CONFIG} ]; then
  touch ${JAVA_CONFIG} && chmod 644 ${JAVA_CONFIG}
fi

chmod 644 ${JAVA_CONFIG}

# END fix for 'java_jre_deployment_config_exists'

###############################################################################
# BEGIN fix (23 / 24) for 'java_jre_accepted_sites_exists'
###############################################################################
(>&2 echo "Remediating rule 23/24: 'java_jre_accepted_sites_exists'")
JAVA_FILE="/etc/.java/deployment/exception.sites"
JAVA_DIR="/etc/.java/deployment"

if [ ! -d ${JAVA_DIR} ] ; then
  mkdir -p -m 755 ${JAVA_DIR}
fi

if [ ! -e ${JAVA_FILE} ]; then
  touch ${JAVA_FILE} && chmod 644 ${JAVA_FILE}
fi

chmod 644 ${JAVA_FILE}

# END fix for 'java_jre_accepted_sites_exists'

###############################################################################
# BEGIN fix (24 / 24) for 'java_jre_accepted_sites_properties'
###############################################################################
(>&2 echo "Remediating rule 24/24: 'java_jre_accepted_sites_properties'")
JAVA_FILE="/etc/.java/deployment/exception.sites"
JAVA_PROPERTIES="/etc/.java/deployment/deployment.properties"

grep -q "^deployment.user.security.exception.sites=.*" ${JAVA_PROPERTIES} && \
sed -i "s;deployment.user.security.exception.sites=.*;deployment.user.security.exception.sites=${JAVA_FILE};g" ${JAVA_PROPERTIES}
if ! [ $? -eq 0 ] ; then
  echo "deployment.user.security.exception.sites=${JAVA_FILE}" >> ${JAVA_PROPERTIES}
fi

# END fix for 'java_jre_accepted_sites_properties'

